from django.db import models
from django.contrib.auth.models import User

class Tweet(models.Model):
    message = models.TextField(blank=True, max_length=140)
    timestamp = models.DateTimeField(auto_now_add=True)
    user = models.ForeignKey(User)
        
    def get_absolute_url(self):
        return u"/user/%s/status/%i/" % (self.user.username, self.id)
        
    def __unicode__(self):
        return u"Tweet from %s: %s" % (self.user.username, self.message)


class Profile(models.Model):
    
    user = models.OneToOneField(User, unique=True)
    followers = models.ManyToManyField("self", blank=True, symmetrical=False, related_name="following")
    bio = models.CharField(blank=True, max_length=200)
    
    def follow_url(self):
        return u"%sfollow" % self.get_absolute_url()
        
    def unfollow_url(self):
        return u"%sunfollow" % self.get_absolute_url()
        
    def tweets(self):
        return Tweet.objects.filter(user=self.user)
        
    def get_absolute_url(self):
        return u"/user/%s/" % self.user.username
        
    def __unicode__(self):
        return u"Profile %s" % self.user.username


def profile_signal_callback(sender, **kwargs):
    if kwargs.get('created'):
        profile = Profile()
        profile.user = User.objects.get(id=kwargs.get('instance').id)
        profile.save()

from django.db.models.signals import post_save
post_save.connect(profile_signal_callback, sender=User, dispatch_uid="users-profilecreation-signal")